@@ -20,7 +20,6 @@
 #include "../kwalletmanager_version.h"
 #include "konfigurator.h"
 
-#include <KSharedConfig>
 #include <KPluginFactory>
 #include <KPluginLoader>
 #include <QInputDialog>
@@ -28,7 +27,6 @@
 #include <KAuthAction>
 #include <KAuthActionReply>
 #include <KAuthExecuteJob>
-#include <KToolInvocation>
 #include <KConfigGroup>
 #include <KMessageBox>
 
