@@ -19,8 +19,8 @@
 
 #include "authorizedappmodel.h"
 #include "kwalletmanager_debug.h"
-#include <kconfiggroup.h>
-#include <kwallet.h>
+#include <KConfigGroup>
+#include <KWallet>
 #include <QTimer>
 
 AuthorizedAppModel::AuthorizedAppModel(KWallet::Wallet *wallet):
