@@ -19,8 +19,8 @@
 
 #include "disconnectappbutton.h"
 
-#include <klocalizedstring.h>
-#include <kwallet.h>
+#include <KLocalizedString>
+#include <KWallet>
 
 DisconnectAppButton::DisconnectAppButton(const QString &appName, KWallet::Wallet *wallet) :
     _appName(appName), _wallet(wallet)
