@@ -28,14 +28,14 @@ class KBetterThanKDialogBase : public QDialog, private Ui_KBetterThanKDialogBase
     Q_OBJECT
 
 public:
-    KBetterThanKDialogBase(QWidget *parent = 0);
+    explicit KBetterThanKDialogBase(QWidget *parent = nullptr);
 
-public slots:
+public Q_SLOTS:
     virtual void setLabel(const QString &label);
     void accept() override;
     void reject() override;
 
-private slots:
+private Q_SLOTS:
     virtual void clicked();
 };
 
