@@ -24,10 +24,10 @@
 #include "kwalletmanager_debug.h"
 
 
-#include <kwallet.h>
+#include <KWallet>
 #include <QUrl>
-#include <kmessagebox.h>
-#include <klocalizedstring.h>
+#include <KMessageBox>
+#include <KLocalizedString>
 #include <QDragEnterEvent>
 
 KWalletManagerWidget::KWalletManagerWidget(QWidget *parent, Qt::WindowFlags /*flags*/):
