@@ -19,12 +19,12 @@
 
 #include "kwalletpopup.h"
 
-#include <kstandardaction.h>
-#include <kactioncollection.h>
+#include <KStandardAction>
+#include <KActionCollection>
 #include <QAction>
-#include <klocalizedstring.h>
-#include <kmessagebox.h>
-#include <kwallet.h>
+#include <KLocalizedString>
+#include <KMessageBox>
+#include <KWallet>
 
 
 KWalletPopup::KWalletPopup(const QString &wallet, QWidget *parent, const QString &name)
